@@ -2,32 +2,26 @@ import os
 import warnings
 import re
 
-# Optionally add telemtry
+# Optionally add telemetry
 from ._version import __version__
 
-from deepeval.event import track
-from deepeval.monitor import monitor, a_monitor, send_feedback, a_send_feedback
 from deepeval.evaluate import evaluate, assert_test
+from deepeval.evaluate.compare import compare
 from deepeval.test_run import on_test_run_end, log_hyperparameters
-from deepeval.utils import login_with_confident_api_key
+from deepeval.utils import login
 from deepeval.telemetry import *
-from deepeval.integrations import trace_langchain, trace_llama_index
-from deepeval.confident import confident_evaluate
+
+if os.getenv("DEEPEVAL_GRPC_LOGGING") != "YES":
+    os.environ["GRPC_VERBOSITY"] = "ERROR"
+    os.environ["GRPC_TRACE"] = ""
 
 __all__ = [
-    "login_with_confident_api_key",
+    "login",
     "log_hyperparameters",
-    "track",
-    "monitor",
-    "a_monitor",
-    "a_send_feedback",
-    "send_feedback",
     "evaluate",
     "assert_test",
     "on_test_run_end",
-    "trace_langchain",
-    "trace_llama_index",
-    "confident_evaluate",
+    "compare",
 ]
 
 
@@ -62,13 +56,17 @@ def check_for_update():
             # when pypi servers go down
             pass
     except ModuleNotFoundError:
-        # they're just getting the versione
+        # they're just getting the versions
         pass
 
 
-def update_warning_opt_out():
-    return os.getenv("DEEPEVAL_UPDATE_WARNING_OPT_OUT") == "YES"
+def update_warning_opt_in():
+    return os.getenv("DEEPEVAL_UPDATE_WARNING_OPT_IN") == "YES"
 
 
-if not update_warning_opt_out():
+def is_read_only_env():
+    return os.getenv("DEEPEVAL_FILE_SYSTEM") == "READ_ONLY"
+
+
+if update_warning_opt_in():
     check_for_update()
