@@ -1,15 +1,15 @@
 from typing import List, Dict, Optional
-from datasets import load_dataset
 from tqdm import tqdm
-import pandas as pd
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.hellaswag.task import HellaSwagTask
 from deepeval.benchmarks.hellaswag.template import HellaSwagTemplate
 from deepeval.benchmarks.utils import should_use_batch
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import MultipleChoiceSchema
 from deepeval.telemetry import capture_benchmark_run
 
@@ -24,6 +24,9 @@ class HellaSwag(DeepEvalBaseBenchmark):
         confinement_instructions: Optional[str] = None,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         assert n_shots <= 15, "HellaSwag only supports n_shots <= 15."
         super().__init__(**kwargs)
         self.tasks: List[HellaSwagTask] = (
@@ -45,8 +48,14 @@ class HellaSwag(DeepEvalBaseBenchmark):
             self.confinement_instructions = confinement_instructions
 
     def evaluate(
-        self, model: DeepEvalBaseLLM, batch_size: Optional[int] = None
-    ) -> Dict:
+        self,
+        model: DeepEvalBaseLLM,
+        *args,
+        batch_size: int | None = None,
+        **kwargs,
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("HellaSwag", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = 0
@@ -120,9 +129,12 @@ class HellaSwag(DeepEvalBaseBenchmark):
                                 score,
                             )
 
-                task_accuracy = (
-                    task_correct_predictions / task_total_predictions
-                )
+                if task_total_predictions == 0:
+                    task_accuracy = 0
+                else:
+                    task_accuracy = (
+                        task_correct_predictions / task_total_predictions
+                    )
                 print(
                     f"HellaSwag Task Accuracy (task={task.value}): {task_accuracy}"
                 )
@@ -151,7 +163,9 @@ class HellaSwag(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(
         self, model: DeepEvalBaseLLM, task: HellaSwagTask, golden: Golden
@@ -237,12 +251,14 @@ class HellaSwag(DeepEvalBaseBenchmark):
         return res
 
     def load_benchmark_dataset(self, task: HellaSwagTask) -> List[Golden]:
+        from datasets import load_dataset
+
         # If dataset has been previously loaded, load from
         # instance var (to save time)
         if self.dataset:
             dataset = self.dataset
         else:
-            dataset = load_dataset("Rowan/hellaswag", trust_remote_code=True)
+            dataset = load_dataset("Rowan/hellaswag")
             self.dataset = dataset
 
         # If dataset has not been previously loaded, construct
