@@ -1,15 +1,15 @@
 from typing import List, Optional, Dict
-from datasets import load_dataset
-import pandas as pd
 from tqdm import tqdm
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.mmlu.task import MMLUTask
 from deepeval.benchmarks.mmlu.template import MMLUTemplate
 from deepeval.benchmarks.utils import should_use_batch
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import MultipleChoiceSchema
 from deepeval.telemetry import capture_benchmark_run
 
@@ -17,13 +17,16 @@ from deepeval.telemetry import capture_benchmark_run
 class MMLU(DeepEvalBaseBenchmark):
     def __init__(
         self,
-        tasks: List[MMLUTask] = None,
+        tasks: Optional[List[MMLUTask]] = None,
         n_shots: int = 5,
         n_problems_per_task: Optional[int] = None,
         verbose_mode: bool = False,
         confinement_instructions: Optional[str] = None,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         assert n_shots <= 5, "MMLU only supports n_shots <= 5"
         super().__init__(**kwargs)
         self.tasks: List[MMLUTask] = list(MMLUTask) if tasks is None else tasks
@@ -43,8 +46,14 @@ class MMLU(DeepEvalBaseBenchmark):
             self.confinement_instructions = confinement_instructions
 
     def evaluate(
-        self, model: DeepEvalBaseLLM, batch_size: Optional[int] = None
-    ) -> Dict:
+        self,
+        model: DeepEvalBaseLLM,
+        *args,
+        batch_size: int | None = None,
+        **kwargs,
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("MMLU", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = 0
@@ -150,16 +159,18 @@ class MMLU(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(
         self, model: DeepEvalBaseLLM, task: MMLUTask, golden: Golden
     ) -> Dict:
         # Define prompt template
         assert (
-            self.shots_dataset != None
+            self.shots_dataset
         ), "Example dataset is empty. Call load_benchmark."
-        prompt: dict = MMLUTemplate.generate_output(
+        prompt = MMLUTemplate.generate_output(
             train_set=self.shots_dataset,
             input=golden.input,
             task=task,
@@ -171,7 +182,10 @@ class MMLU(DeepEvalBaseBenchmark):
             res: MultipleChoiceSchema = model.generate(
                 prompt=prompt, schema=MultipleChoiceSchema
             )
-            prediction = res.answer
+            if isinstance(res, (tuple, list)):
+                prediction = res[0].answer
+            else:
+                prediction = res.answer
         except TypeError:
             prompt += f"\n\n{self.confinement_instructions}"
             prediction = model.generate(prompt)
@@ -192,12 +206,12 @@ class MMLU(DeepEvalBaseBenchmark):
     ) -> List[Dict]:
         # Define prompt template
         assert (
-            self.shots_dataset != None
+            self.shots_dataset
         ), "Example dataset is empty. Call load_benchmark."
 
         prompts = []
         for golden in goldens:
-            prompt: dict = MMLUTemplate.generate_output(
+            prompt = MMLUTemplate.generate_output(
                 train_set=self.shots_dataset,
                 input=golden.input,
                 task=task,
@@ -210,7 +224,10 @@ class MMLU(DeepEvalBaseBenchmark):
             responses: List[MultipleChoiceSchema] = model.batch_generate(
                 prompts=prompts, schemas=[MultipleChoiceSchema for i in prompts]
             )
-            predictions = [res.answer for res in responses]
+            if isinstance(responses, (tuple, list)):
+                predictions = [res[0].answer for res in responses]
+            else:
+                predictions = [res.answer for res in responses]
         except TypeError:
             prompts = [
                 prompt
@@ -237,16 +254,18 @@ class MMLU(DeepEvalBaseBenchmark):
         return res
 
     def load_benchmark_dataset(self, task: MMLUTask) -> List[Golden]:
+        from datasets import load_dataset
 
         dataset = load_dataset(
-            "lukaemon/mmlu", task.value, trust_remote_code=True
+            "cais/mmlu",
+            task.value,
         )
         self.dataset = dataset
 
         # If dataset has not been previously loaded, construct
         # dataset of examples and save as instance var (to save time)
         if not self.shots_dataset:
-            train_set = dataset["train"]
+            train_set = dataset["dev"]
             shots_set = []
             for data in train_set:
                 shots_set.append(data)
@@ -254,9 +273,12 @@ class MMLU(DeepEvalBaseBenchmark):
 
         # Construct test set
         goldens: List[Golden] = []
+        choices = ["A", "B", "C", "D"]
         for data in dataset["test"]:
             input = MMLUTemplate.format_question(data, include_answer=False)
-            golden = Golden(input=input, expected_output=data["target"])
+            golden = Golden(
+                input=input, expected_output=choices[data["answer"]]
+            )
             goldens.append(golden)
         return goldens
 
