@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import List, Optional, Type, Union
 
 from deepeval.metrics import BaseMetric
 from deepeval.test_case import (
@@ -15,17 +15,17 @@ from deepeval.metrics.utils import (
     check_llm_test_case_params,
     initialize_model,
 )
-from deepeval.metrics.bias.template import BiasTemplate
 from deepeval.metrics.toxicity.template import ToxicityTemplate
 from deepeval.metrics.toxicity.schema import *
 
-required_params: List[LLMTestCaseParams] = [
-    LLMTestCaseParams.INPUT,
-    LLMTestCaseParams.ACTUAL_OUTPUT,
-]
-
 
 class ToxicityMetric(BaseMetric):
+
+    _required_params: List[LLMTestCaseParams] = [
+        LLMTestCaseParams.INPUT,
+        LLMTestCaseParams.ACTUAL_OUTPUT,
+    ]
+
     def __init__(
         self,
         threshold: float = 0.5,
@@ -34,6 +34,7 @@ class ToxicityMetric(BaseMetric):
         async_mode: bool = True,
         strict_mode: bool = False,
         verbose_mode: bool = False,
+        evaluation_template: Type[ToxicityTemplate] = ToxicityTemplate,
     ):
         self.threshold = 0 if strict_mode else threshold
         self.model, self.using_native_model = initialize_model(model)
@@ -42,22 +43,29 @@ class ToxicityMetric(BaseMetric):
         self.async_mode = async_mode
         self.strict_mode = strict_mode
         self.verbose_mode = verbose_mode
+        self.evaluation_template = evaluation_template
 
     def measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
-        with metric_progress_indicator(self, _show_indicator=_show_indicator):
+        with metric_progress_indicator(
+            self, _show_indicator=_show_indicator, _in_component=_in_component
+        ):
             if self.async_mode:
                 loop = get_or_create_event_loop()
                 loop.run_until_complete(
-                    self.a_measure(test_case, _show_indicator=False)
+                    self.a_measure(
+                        test_case,
+                        _show_indicator=False,
+                        _in_component=_in_component,
+                    )
                 )
             else:
                 self.opinions: List[str] = self._generate_opinions(
@@ -77,20 +85,23 @@ class ToxicityMetric(BaseMetric):
                     ],
                 )
 
-                return self.score
+            return self.score
 
     async def a_measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
         with metric_progress_indicator(
-            self, async_mode=True, _show_indicator=_show_indicator
+            self,
+            async_mode=True,
+            _show_indicator=_show_indicator,
+            _in_component=_in_component,
         ):
             self.opinions: List[str] = await self._a_generate_opinions(
                 test_case.actual_output
@@ -123,18 +134,22 @@ class ToxicityMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "yes":
                 toxics.append(verdict.reason)
 
-        prompt: dict = ToxicityTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             toxics=toxics,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = await self.model.a_generate(prompt, schema=Reason)
+            res, cost = await self.model.a_generate(
+                prompt, schema=ToxicityScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = await self.model.a_generate(prompt, schema=Reason)
+                res: ToxicityScoreReason = await self.model.a_generate(
+                    prompt, schema=ToxicityScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = await self.model.a_generate(prompt)
@@ -150,18 +165,20 @@ class ToxicityMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "yes":
                 toxics.append(verdict.reason)
 
-        prompt: dict = ToxicityTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             toxics=toxics,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Reason)
+            res, cost = self.model.generate(prompt, schema=ToxicityScoreReason)
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = self.model.generate(prompt, schema=Reason)
+                res: ToxicityScoreReason = self.model.generate(
+                    prompt, schema=ToxicityScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = self.model.generate(prompt)
@@ -173,7 +190,9 @@ class ToxicityMetric(BaseMetric):
             return []
 
         verdicts: List[ToxicityVerdict] = []
-        prompt = ToxicityTemplate.generate_verdicts(opinions=self.opinions)
+        prompt = self.evaluation_template.generate_verdicts(
+            opinions=self.opinions
+        )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Verdicts)
             self.evaluation_cost += cost
@@ -199,7 +218,9 @@ class ToxicityMetric(BaseMetric):
             return []
 
         verdicts: List[ToxicityVerdict] = []
-        prompt = ToxicityTemplate.generate_verdicts(opinions=self.opinions)
+        prompt = self.evaluation_template.generate_verdicts(
+            opinions=self.opinions
+        )
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Verdicts)
             self.evaluation_cost += cost
@@ -219,7 +240,9 @@ class ToxicityMetric(BaseMetric):
                 return verdicts
 
     async def _a_generate_opinions(self, actual_output: str) -> List[str]:
-        prompt = BiasTemplate.generate_opinions(actual_output=actual_output)
+        prompt = self.evaluation_template.generate_opinions(
+            actual_output=actual_output
+        )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Opinions)
             self.evaluation_cost += cost
@@ -236,7 +259,9 @@ class ToxicityMetric(BaseMetric):
                 return data["opinions"]
 
     def _generate_opinions(self, actual_output: str) -> List[str]:
-        prompt = BiasTemplate.generate_opinions(actual_output=actual_output)
+        prompt = self.evaluation_template.generate_opinions(
+            actual_output=actual_output
+        )
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Opinions)
             self.evaluation_cost += cost
