@@ -1,70 +1,103 @@
-from langchain_core.documents import Document as LCDocument
-from langchain_community.document_loaders import (
-    PyPDFLoader,
-    TextLoader,
-    Docx2txtLoader,
-)
-from langchain_community.document_loaders.base import BaseLoader
-from langchain_text_splitters import TokenTextSplitter
-from langchain_text_splitters.base import TextSplitter
-from typing import Optional, List, Dict
+from typing import Optional, List, Dict, Union, Type
 import os
 
 from deepeval.models.base_model import DeepEvalBaseEmbeddingModel
 
+# check langchain availability
+try:
+    from langchain_core.documents import Document as LCDocument
+    from langchain_text_splitters import TokenTextSplitter
+    from langchain_text_splitters.base import TextSplitter
+    from langchain_community.document_loaders import (
+        PyPDFLoader,
+        TextLoader,
+        Docx2txtLoader,
+    )
+    from langchain_community.document_loaders.base import BaseLoader
+
+    langchain_available = True
+except ImportError:
+    langchain_available = False
+
+# check chromadb availability
+try:
+    import chromadb
+    from chromadb import Metadata
+    from chromadb.api.models.Collection import Collection
+
+    chroma_db_available = True
+except ImportError:
+    chroma_db_available = False
+
+
+# Define a helper function to check availability
+def _check_chromadb_available():
+    if not chroma_db_available:
+        raise ImportError(
+            "chromadb is required for this functionality. Install it via your package manager"
+        )
+
+
+def _check_langchain_available():
+    if not langchain_available:
+        raise ImportError(
+            "langchain, langchain_community, and langchain_text_splitters are required for this functionality. Install it via your package manager"
+        )
+
 
 class DocumentChunker:
     def __init__(
         self,
         embedder: DeepEvalBaseEmbeddingModel,
-        chunk_size: int = 1024,
-        chunk_overlap: int = 0,
     ):
-        from chromadb.api.models.Collection import Collection
+        _check_chromadb_available()
+        _check_langchain_available()
+        self.text_token_count: Optional[int] = None  # set later
 
         self.source_file: Optional[str] = None
-        self.chunk_size = chunk_size
-        self.chunk_overlap = chunk_overlap
-        self.chunks: Optional[Collection] = None
+        self.chunks: Optional["Collection"] = None
         self.sections: Optional[List[LCDocument]] = None
-
-        self.text_splitter: TextSplitter = TokenTextSplitter(
-            chunk_size=chunk_size, chunk_overlap=chunk_overlap
-        )
         self.embedder: DeepEvalBaseEmbeddingModel = embedder
         self.mean_embedding: Optional[float] = None
 
         # Mapping of file extensions to their respective loader classes
-        self.loader_mapping: Dict[str, BaseLoader] = {
+        self.loader_mapping: Dict[str, Type[BaseLoader]] = {
             ".pdf": PyPDFLoader,
             ".txt": TextLoader,
             ".docx": Docx2txtLoader,
         }
 
-    async def a_chunk_doc(self) -> List[LCDocument]:
+    #########################################################
+    ### Chunking Docs #######################################
+    #########################################################
+
+    async def a_chunk_doc(
+        self, chunk_size: int = 1024, chunk_overlap: int = 0
+    ) -> "Collection":
+        _check_chromadb_available()
+
         # Raise error if chunk_doc is called before load_doc
-        if self.sections == None:
+        if self.sections is None or self.source_file is None:
             raise ValueError(
                 "Document Chunker has yet to properly load documents"
             )
 
-        import chromadb
-
         # Create ChromaDB client
         full_document_path, _ = os.path.splitext(self.source_file)
         document_name = os.path.basename(full_document_path)
         client = chromadb.PersistentClient(path=f".vector_db/{document_name}")
 
-        collection_name = (
-            f"processed_chunks_{self.chunk_size}_{self.chunk_overlap}"
-        )
+        collection_name = f"processed_chunks_{chunk_size}_{chunk_overlap}"
         try:
             collection = client.get_collection(name=collection_name)
-        except chromadb.errors.InvalidCollectionException:
+        except Exception:
+            text_splitter: TextSplitter = TokenTextSplitter(
+                chunk_size=chunk_size, chunk_overlap=chunk_overlap
+            )
             # Collection doesn't exist, so create it and then add documents
             collection = client.create_collection(name=collection_name)
 
-            langchain_chunks = self.text_splitter.split_documents(self.sections)
+            langchain_chunks = text_splitter.split_documents(self.sections)
             contents = [rc.page_content for rc in langchain_chunks]
             embeddings = await self.embedder.a_embed_texts(contents)
             ids = [str(i) for i in range(len(contents))]
@@ -75,7 +108,7 @@ class DocumentChunker:
                 batch_contents = contents[i:batch_end]
                 batch_embeddings = embeddings[i:batch_end]
                 batch_ids = ids[i:batch_end]
-                batch_metadatas = [
+                batch_metadatas: List["Metadata"] = [
                     {"source_file": self.source_file} for _ in batch_contents
                 ]
 
@@ -87,37 +120,31 @@ class DocumentChunker:
                 )
         return collection
 
-    def chunk_doc(self):
+    def chunk_doc(self, chunk_size: int = 1024, chunk_overlap: int = 0):
+        _check_chromadb_available()
+
         # Raise error if chunk_doc is called before load_doc
-        if self.sections == None:
+        if self.sections is None or self.source_file is None:
             raise ValueError(
                 "Document Chunker has yet to properly load documents"
             )
 
-        import chromadb
-
         # Create ChromaDB client
         full_document_path, _ = os.path.splitext(self.source_file)
         document_name = os.path.basename(full_document_path)
         client = chromadb.PersistentClient(path=f".vector_db/{document_name}")
 
-        try:
-            collection = client.get_collection(
-                name=f"processed_chunks_{self.chunk_size}_{self.chunk_overlap}"
-            )
-            return collection
-
-        except:
-            collection_name = (
-                f"processed_chunks_{self.chunk_size}_{self.chunk_overlap}"
-            )
+        collection_name = f"processed_chunks_{chunk_size}_{chunk_overlap}"
         try:
             collection = client.get_collection(name=collection_name)
-        except:
+        except Exception:
+            text_splitter: TextSplitter = TokenTextSplitter(
+                chunk_size=chunk_size, chunk_overlap=chunk_overlap
+            )
             # Collection doesn't exist, so create it and then add documents
             collection = client.create_collection(name=collection_name)
 
-            langchain_chunks = self.text_splitter.split_documents(self.sections)
+            langchain_chunks = text_splitter.split_documents(self.sections)
             contents = [rc.page_content for rc in langchain_chunks]
             embeddings = self.embedder.embed_texts(contents)
             ids = [str(i) for i in range(len(contents))]
@@ -128,7 +155,7 @@ class DocumentChunker:
                 batch_contents = contents[i:batch_end]
                 batch_embeddings = embeddings[i:batch_end]
                 batch_ids = ids[i:batch_end]
-                batch_metadatas = [
+                batch_metadatas: List["Metadata"] = [
                     {"source_file": self.source_file} for _ in batch_contents
                 ]
 
@@ -140,34 +167,38 @@ class DocumentChunker:
                 )
         return collection
 
-    async def a_load_doc(self, path: str) -> List[LCDocument]:
-        # Find appropiate doc loader
+    #########################################################
+    ### Loading Docs ########################################
+    #########################################################
+
+    def get_loader(self, path: str, encoding: Optional[str]) -> "BaseLoader":
+        # Find appropriate doc loader
         _, extension = os.path.splitext(path)
         extension = extension.lower()
-        loader: Optional[BaseLoader] = self.loader_mapping.get(extension)
+        loader: Optional[type[BaseLoader]] = self.loader_mapping.get(extension)
         if loader is None:
             raise ValueError(f"Unsupported file format: {extension}")
 
         # Load doc into sections and calculate total character count
-        loader = loader(path)
+        if loader is TextLoader:
+            return loader(path, encoding=encoding, autodetect_encoding=True)
+        elif loader is PyPDFLoader or loader is Docx2txtLoader:
+            return loader(path)
+        else:
+            raise ValueError(f"Unsupported file format: {extension}")
+
+    async def a_load_doc(self, path: str, encoding: Optional[str]):
+        loader = self.get_loader(path, encoding)
         self.sections = await loader.aload()
         self.text_token_count = self.count_tokens(self.sections)
         self.source_file = path
 
-    def load_doc(self, path: str):
-        # Find appropiate doc loader
-        _, extension = os.path.splitext(path)
-        extension = extension.lower()
-        loader: Optional[BaseLoader] = self.loader_mapping.get(extension)
-        if loader is None:
-            raise ValueError(f"Unsupported file format: {extension}")
-
-        # Load doc into sections and calculate total character count
-        loader = loader(path)
+    def load_doc(self, path: str, encoding: Optional[str]):
+        loader = self.get_loader(path, encoding)
         self.sections = loader.load()
         self.text_token_count = self.count_tokens(self.sections)
         self.source_file = path
 
-    def count_tokens(self, chunks: LCDocument):
+    def count_tokens(self, chunks: List["LCDocument"]):
         counter = TokenTextSplitter(chunk_size=1, chunk_overlap=0)
         return len(counter.split_documents(chunks))
