@@ -1,38 +1,37 @@
-from pydantic import BaseModel, Field, ConfigDict, model_validator
-from typing import Any, Optional, List, Union, Dict
+from pydantic import BaseModel, Field, ConfigDict
+from typing import Optional, List, Union, Dict
 
-from deepeval.test_case import MLLMImage
-
-
-class MetricData(BaseModel):
-    name: str
-    threshold: float
-    success: bool
-    score: Optional[float] = None
-    reason: Optional[str] = None
-    strict_mode: Optional[bool] = Field(False, alias="strictMode")
-    evaluation_model: Optional[str] = Field(None, alias="evaluationModel")
-    error: Optional[str] = None
-    evaluation_cost: Union[float, None] = Field(None, alias="evaluationCost")
-    verbose_logs: Optional[str] = Field(None, alias="verboseLogs")
+from deepeval.test_case import MLLMImage, ToolCall
+from deepeval.tracing.api import TraceApi, MetricData
 
 
 class LLMApiTestCase(BaseModel):
     name: str
-    input: Optional[str] = None
+    input: str
     actual_output: Optional[str] = Field(None, alias="actualOutput")
     expected_output: Optional[str] = Field(None, alias="expectedOutput")
     context: Optional[list] = Field(None)
     retrieval_context: Optional[list] = Field(None, alias="retrievalContext")
     tools_called: Optional[list] = Field(None, alias="toolsCalled")
     expected_tools: Optional[list] = Field(None, alias="expectedTools")
-
+    token_cost: Optional[float] = Field(None, alias="tokenCost")
+    completion_time: Optional[float] = Field(None, alias="completionTime")
+    tags: Optional[List[str]] = Field(None)
     multimodal_input: Optional[List[Union[str, MLLMImage]]] = Field(
         None, alias="multimodalInput"
     )
     multimodal_input_actual_output: Optional[List[Union[str, MLLMImage]]] = (
         Field(None, alias="multimodalActualOutput")
     )
+    multimodal_expected_output: Optional[List[Union[str, MLLMImage]]] = Field(
+        None, alias="multimodalExpectedOutput"
+    )
+    multimodal_retrieval_context: Optional[List[Union[str, MLLMImage]]] = Field(
+        None, alias="multimodalRetrievalContext"
+    )
+    multimodal_context: Optional[List[Union[str, MLLMImage]]] = Field(
+        None, alias="multimodalContext"
+    )
 
     # make these optional, not all test cases in a conversation will be evaluated
     success: Union[bool, None] = Field(None)
@@ -48,7 +47,7 @@ class LLMApiTestCase(BaseModel):
         None, alias="additionalMetadata"
     )
     comments: Optional[str] = Field(None)
-    conversational_instance_id: Optional[int] = Field(None)
+    trace: Optional[TraceApi] = Field(None)
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
@@ -78,22 +77,12 @@ class LLMApiTestCase(BaseModel):
     def update_run_duration(self, run_duration: float):
         self.run_duration = run_duration
 
-    @model_validator(mode="before")
-    def check_input_and_multimodal_input(cls, values: Dict[str, Any]):
-        input = values.get("input")
-        actual_output = values.get("actualOutput")
-        multimodal_input = values.get("multimodalInput")
-        multimodal_actual_output = values.get("multimodalActualOutput")
-
-        # Ensure that either input/actual_output or multimodal_input/multimodal_actual_output is present
-        if (input is None or actual_output is None) and (
-            multimodal_input is None or multimodal_actual_output is None
-        ):
-            raise ValueError(
-                "Either 'input' and 'actualOutput' or 'multimodalInput' and 'multimodalActualOutput' must be provided."
-            )
-
-        return values
+    def update_status(self, success: bool):
+        if self.success is None:
+            self.success = success
+        else:
+            if success is False:
+                self.success = False
 
     def is_multimodal(self):
         if (
@@ -105,18 +94,35 @@ class LLMApiTestCase(BaseModel):
         return False
 
 
+class TurnApi(BaseModel):
+    role: str
+    content: str
+    order: int
+    retrieval_context: Optional[list] = Field(None, alias="retrievalContext")
+    tools_called: Optional[List[ToolCall]] = Field(None, alias="toolsCalled")
+    additional_metadata: Optional[Dict] = Field(
+        None, alias="additionalMetadata"
+    )
+    comments: Optional[str] = Field(None)
+
+
 class ConversationalApiTestCase(BaseModel):
     name: str
     success: bool
-    instance_id: Optional[int] = Field(None)
-    # metrics_data can never be None
     metrics_data: List[MetricData] = Field(alias="metricsData")
     run_duration: float = Field(0.0, alias="runDuration")
     evaluation_cost: Union[float, None] = Field(None, alias="evaluationCost")
-    turns: List[LLMApiTestCase] = Field(
-        default_factory=lambda: [], alias="testCases"
-    )
+    turns: List[TurnApi] = Field(default_factory=lambda: [])
     order: Union[int, None] = Field(None)
+    scenario: Optional[str] = Field(None)
+    expected_outcome: Optional[str] = Field(None, alias="expectedOutcome")
+    user_description: Optional[str] = Field(None, alias="userDescription")
+    context: Optional[list] = Field(None)
+    comments: Optional[str] = Field(None)
+    additional_metadata: Optional[Dict] = Field(
+        None, alias="additionalMetadata"
+    )
+    tags: Optional[List[str]] = Field(None)
 
     def update_metric_data(self, metrics_data: MetricData):
         if self.metrics_data is None:
@@ -141,6 +147,4 @@ class ConversationalApiTestCase(BaseModel):
 
 
 class TestRunHttpResponse(BaseModel):
-    testRunId: str
-    projectId: str
-    link: str
+    id: str
