@@ -6,18 +6,21 @@ import json
 import time
 from typing import Any, Optional, Dict, List, Union
 from collections.abc import Iterable
+import webbrowser
 import tqdm
 import re
 import string
-import numpy as np
 from dataclasses import asdict, is_dataclass
 import re
 import asyncio
 import nest_asyncio
 import uuid
 from pydantic import BaseModel
+from rich.progress import Progress
+from rich.console import Console, Theme
 
-from deepeval.key_handler import KeyValues, KEY_FILE_HANDLER
+from deepeval.confident.api import set_confident_api_key
+from deepeval.constants import CONFIDENT_OPEN_BROWSER
 
 
 def get_lcs(seq1, seq2):
@@ -54,10 +57,16 @@ def camel_to_snake(name: str) -> str:
 
 def convert_keys_to_snake_case(data: Any) -> Any:
     if isinstance(data, dict):
-        return {
-            camel_to_snake(k): convert_keys_to_snake_case(v)
-            for k, v in data.items()
-        }
+        new_dict = {}
+        for k, v in data.items():
+            new_key = camel_to_snake(k)
+            if k == "additionalMetadata":
+                new_dict[new_key] = (
+                    v  # Convert key but do not recurse into value
+                )
+            else:
+                new_dict[new_key] = convert_keys_to_snake_case(v)
+        return new_dict
     elif isinstance(data, list):
         return [convert_keys_to_snake_case(i) for i in data]
     else:
@@ -80,7 +89,9 @@ def prettify_list(lst: List[Any]):
                 jsonObj = item.dict()
 
             formatted_elements.append(
-                json.dumps(jsonObj, indent=4).replace("\n", "\n    ")
+                json.dumps(jsonObj, indent=4, ensure_ascii=True).replace(
+                    "\n", "\n    "
+                )
             )
         else:
             formatted_elements.append(repr(item))  # Fallback for other types
@@ -119,9 +130,6 @@ def get_or_create_event_loop() -> asyncio.AbstractEventLoop:
     try:
         loop = asyncio.get_event_loop()
         if loop.is_running():
-            print(
-                "Event loop is already running. Applying nest_asyncio patch to allow async execution..."
-            )
             nest_asyncio.apply()
 
         if loop.is_closed():
@@ -181,6 +189,18 @@ def set_verbose_mode(yes: Optional[bool]):
         os.environ["DEEPEVAL_VERBOSE_MODE"] = "YES"
 
 
+def set_identifier(identifier: Optional[str]):
+    if identifier:
+        os.environ["DEEPEVAL_IDENTIFIER"] = identifier
+
+
+def get_identifier() -> Optional[str]:
+    try:
+        return os.environ["DEEPEVAL_IDENTIFIER"]
+    except:
+        return None
+
+
 def should_use_cache():
     try:
         if os.environ["ENABLE_DEEPEVAL_CACHE"] == "YES":
@@ -198,11 +218,18 @@ def set_should_use_cache(yes: bool):
         os.environ["ENABLE_DEEPEVAL_CACHE"] = "NO"
 
 
-def login_with_confident_api_key(api_key: string):
+def login(api_key: str):
+    if not api_key or not isinstance(api_key, str):
+        raise ValueError("Oh no! Please provide an api key string to login.")
+    elif len(api_key) == 0:
+        raise ValueError("Unable to login, please provide a non-empty api key.")
+
     from rich import print
 
-    KEY_FILE_HANDLER.write_key(KeyValues.API_KEY, api_key)
-    print("Congratulations! Login successful :raising_hands: ")
+    set_confident_api_key(api_key)
+    print(
+        "🎉🥳 Congratulations! You've successfully logged in! :raising_hands: "
+    )
 
 
 def set_is_running_deepeval(flag: bool):
@@ -242,9 +269,10 @@ def is_in_ci_env() -> bool:
     return False
 
 
-def is_confident():
-    confident_api_key = KEY_FILE_HANDLER.fetch_data(KeyValues.API_KEY)
-    return confident_api_key is not None
+def open_browser(url: str):
+    if os.getenv(CONFIDENT_OPEN_BROWSER) != "NO":
+        if is_in_ci_env() == False:
+            webbrowser.open(url)
 
 
 def capture_contextvars(single_obj):
@@ -357,11 +385,15 @@ def delete_file_if_exists(file_path):
 
 
 def softmax(x):
+    import numpy as np
+
     e_x = np.exp(x - np.max(x, axis=1, keepdims=True))
     return e_x / e_x.sum(axis=1, keepdims=True)
 
 
 def cosine_similarity(vector_a, vector_b):
+    import numpy as np
+
     dot_product = np.dot(vector_a, vector_b)
     norm_a = np.linalg.norm(vector_a)
     norm_b = np.linalg.norm(vector_b)
@@ -463,3 +495,53 @@ def clean_nested_dict(data):
         return data.replace("\x00", "")
     else:
         return data
+
+
+def update_pbar(
+    progress: Optional[Progress],
+    pbar_id: Optional[int],
+    advance: int = 1,
+    advance_to_end: bool = False,
+    remove: bool = True,
+    total: Optional[int] = None,
+):
+    if progress is None or pbar_id is None:
+        return
+    # Get amount to advance
+    current_task = next(t for t in progress.tasks if t.id == pbar_id)
+    if advance_to_end:
+        advance = current_task.remaining
+    # Advance
+    progress.update(pbar_id, advance=advance, total=total)
+    # Remove if finished
+    if current_task.finished and remove:
+        progress.remove_task(pbar_id)
+
+
+def add_pbar(progress: Optional[Progress], description: str, total: int = 1):
+    if progress is None:
+        return None
+    return progress.add_task(description, total=total)
+
+
+def remove_pbars(
+    progress: Optional[Progress], pbar_ids: List[int], cascade: bool = True
+):
+    if progress is None:
+        return
+    for pbar_id in pbar_ids:
+        if cascade:
+            time.sleep(0.1)
+        progress.remove_task(pbar_id)
+
+
+my_theme = Theme(
+    {
+        "bar.complete": "#11ff00",
+        "progress.percentage": "#00e5ff",
+        # "progress.data.speed": "#00FF00",
+        # "progress.remaining": "#00FF00",
+        "progress.elapsed": "#5703ff",
+    }
+)
+custom_console = Console(theme=my_theme)
